/* eslint-disable */
import React from 'react';
import { Link } from 'react-router-dom';
import { Row, Col, Icon, Button, Select, message, Modal, Divider, Avatar } from 'antd';
import TableView from '../../components/common/TableView';
import SearchFormView from '../../components/common/SearchFormView';
import moment from 'moment';
import fetch from '../../api/request';

const confirm = Modal.confirm;

export default class UserManage extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      formData: {
        __key: Date.now(),
        page: 1,
        size: 10,
      },
      userSyncLoading: false
    };
  }

  componentDidMount() { }

  setFormData = data => {
    this.setState({
      formData: data,
    });
  }

  // 新增用户
  add = () => {
    this.props.history.push('/baseManage/user/Detail/new/Add')
  }

  // 微信同步
  userSync = () => {
    this.setState({ userSyncLoading: true })
    fetch({
      url: `api/user/syncCpUser`
    }).then(res => {
      this.setState({ userSyncLoading: false });
      if (res) {
        message.success("同步成功！");
        this.setState({
          formData: {
            ...this.state.formData,
            __key: Date.now()
          }
        })
      }
    })
  }

  //表格列显示
  renderColumns = () => {
    return [
      { title: '头像', className: "txt-c", dataIndex: 'avatar', key: 'avatar', render: (text, record) => text ? <image style={{ height: 23, width: 25 }} src={text} /> : <Avatar icon="user" /> },
      { title: '姓名', className: "txt-c", dataIndex: 'trueName', key: 'trueName' },
      { title: '身份证', className: "txt-c", dataIndex: 'idcard', key: 'idcard' },
      { title: '邮箱', className: "txt-c", dataIndex: 'email', key: 'email' },
      { title: '手机号码', className: "txt-c", dataIndex: 'mobile', key: 'mobile' },
      { title: '创建时间', className: "txt-c", dataIndex: 'createTime', key: 'createTime', render: (text, record) => text !== "" && text != null ? moment(text).format("YYYY-MM-DD HH:mm") : "" },
      {
        title: '操作', className: "txt-c", key: 'operation', render: (text, record) => {
          return <div>
            <Link to={{ pathname: "/baseManage/user/Detail/" + record.id + '/Modify', query: { id: record.id } }}>修改</Link>
            <Divider type="vertical" />
            <a onClick={() => this.delete(record.id)}>删除</a>
          </div>
        }
      }
    ]
  }

  //删除用户
  delete = (id) => {
    let _this = this;
    confirm({
      title: <span style={{ fontSize: 19 }}>确定要删除该用户吗？</span>,
      onOk() {
        fetch({
          url: 'api/user/delete',
          params: {
            ids: id
          }
        }).then(res => {
          if (res) {
            message.success("删除成功");
            _this.setState({
              formData: {
                ..._this.state.formData,
                __key: Date.now()
              }
            })
          }
        })
      },
      onCancel() { },
    });
  }

  render() {
    const { formData, userSyncLoading } = this.state;
    let tableParams = {
      url: `api/user/query`,
      formData,
      key: formData.__key,
      columns: this.renderColumns(),
      extraFromData: {},
      setFormData: this.setFormData
    }

    return (
      <div className="usermanage-main margin padding bg-white">
        <SearchFormView
          formData={formData}
          setFormData={this.setFormData}
          data={[
            { type: 'input', name: '姓名', label: '姓名', key: 'trueName' },
            { type: 'input', name: '身份证号码', label: '身份证号码', key: 'idcard' },
            { type: 'input', name: '手机号码', label: '手机号码', key: 'mobile' },
            { type: 'input', name: '电子邮箱', label: '电子邮箱', key: 'email' },
          ]} />
        <Row type="flex" gutter={20} className="margin-bottom">
          <Col>
            <Button type="primary" loading={userSyncLoading} onClick={this.userSync}>同步微信用户</Button>
          </Col>
          <Col>
            <Button type="primary" onClick={this.add}>新增用户</Button>
          </Col>
        </Row>
        <TableView {...tableParams} />
      </div>
    )
  }
}
